# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/datatransfer/v1/transfer_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.datatransfer.v1 import transfer_pb2 as yandex_dot_cloud_dot_datatransfer_dot_v1_dot_transfer__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/datatransfer/v1/transfer_service.proto',
  package='yandex.cloud.datatransfer.v1',
  syntax='proto3',
  serialized_options=b'\n yandex.cloud.api.datatransfer.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1;datatransfer',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n3yandex/cloud/datatransfer/v1/transfer_service.proto\x12\x1cyandex.cloud.datatransfer.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a+yandex/cloud/datatransfer/v1/transfer.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\"\xad\x02\n\x15\x43reateTransferRequest\x12\x11\n\tsource_id\x18\x01 \x01(\t\x12\x11\n\ttarget_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12O\n\x06labels\x18\x08 \x03(\x0b\x32?.yandex.cloud.datatransfer.v1.CreateTransferRequest.LabelsEntry\x12\x11\n\tfolder_id\x18\x04 \x01(\t\x12\x38\n\x04type\x18\x06 \x01(\x0e\x32*.yandex.cloud.datatransfer.v1.TransferType\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"-\n\x16\x43reateTransferMetadata\x12\x13\n\x0btransfer_id\x18\x01 \x01(\t\"\x80\x02\n\x15UpdateTransferRequest\x12\x13\n\x0btransfer_id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12O\n\x06labels\x18\x06 \x03(\x0b\x32?.yandex.cloud.datatransfer.v1.UpdateTransferRequest.LabelsEntry\x12\x0c\n\x04name\x18\x04 \x01(\t\x12/\n\x0bupdate_mask\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"-\n\x16UpdateTransferMetadata\x12\x13\n\x0btransfer_id\x18\x01 \x01(\t\",\n\x15\x44\x65leteTransferRequest\x12\x13\n\x0btransfer_id\x18\x01 \x01(\t\"-\n\x16\x44\x65leteTransferMetadata\x12\x13\n\x0btransfer_id\x18\x01 \x01(\t\"P\n\x14ListTransfersRequest\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12\x11\n\tpage_size\x18\x03 \x01(\x03\x12\x12\n\npage_token\x18\x04 \x01(\t\"k\n\x15ListTransfersResponse\x12\x39\n\ttransfers\x18\x01 \x03(\x0b\x32&.yandex.cloud.datatransfer.v1.Transfer\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\")\n\x12GetTransferRequest\x12\x13\n\x0btransfer_id\x18\x01 \x01(\t\"0\n\x19\x44\x65\x61\x63tivateTransferRequest\x12\x13\n\x0btransfer_id\x18\x01 \x01(\t\"1\n\x1a\x44\x65\x61\x63tivateTransferMetadata\x12\x13\n\x0btransfer_id\x18\x01 \x01(\t\".\n\x17\x41\x63tivateTransferRequest\x12\x13\n\x0btransfer_id\x18\x01 \x01(\t\"/\n\x18\x41\x63tivateTransferMetadata\x12\x13\n\x0btransfer_id\x18\x01 \x01(\t2\xdd\t\n\x0fTransferService\x12\x9f\x01\n\x06\x43reate\x12\x33.yandex.cloud.datatransfer.v1.CreateTransferRequest\x1a!.yandex.cloud.operation.Operation\"=\x82\xd3\xe4\x93\x02\x11\"\x0c/v1/transfer:\x01*\xb2\xd2*\"\n\x16\x43reateTransferMetadata\x12\x08Transfer\x12\xad\x01\n\x06Update\x12\x33.yandex.cloud.datatransfer.v1.UpdateTransferRequest\x1a!.yandex.cloud.operation.Operation\"K\x82\xd3\xe4\x93\x02\x1f\x32\x1a/v1/transfer/{transfer_id}:\x01*\xb2\xd2*\"\n\x16UpdateTransferMetadata\x12\x08Transfer\x12\xb7\x01\n\x06\x44\x65lete\x12\x33.yandex.cloud.datatransfer.v1.DeleteTransferRequest\x1a!.yandex.cloud.operation.Operation\"U\x82\xd3\xe4\x93\x02\x1c*\x1a/v1/transfer/{transfer_id}\xb2\xd2*/\n\x16\x44\x65leteTransferMetadata\x12\x15google.protobuf.Empty\x12\x97\x01\n\x04List\x12\x32.yandex.cloud.datatransfer.v1.ListTransfersRequest\x1a\x33.yandex.cloud.datatransfer.v1.ListTransfersResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/v1/transfers/list/{folder_id}\x12\x83\x01\n\x03Get\x12\x30.yandex.cloud.datatransfer.v1.GetTransferRequest\x1a&.yandex.cloud.datatransfer.v1.Transfer\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/v1/transfer/{transfer_id}\x12\xd1\x01\n\nDeactivate\x12\x37.yandex.cloud.datatransfer.v1.DeactivateTransferRequest\x1a!.yandex.cloud.operation.Operation\"g\x82\xd3\xe4\x93\x02*\"%/v1/transfer/{transfer_id}:deactivate:\x01*\xb2\xd2*3\n\x1a\x44\x65\x61\x63tivateTransferMetadata\x12\x15google.protobuf.Empty\x12\xc9\x01\n\x08\x41\x63tivate\x12\x35.yandex.cloud.datatransfer.v1.ActivateTransferRequest\x1a!.yandex.cloud.operation.Operation\"c\x82\xd3\xe4\x93\x02(\"#/v1/transfer/{transfer_id}:activate:\x01*\xb2\xd2*1\n\x18\x41\x63tivateTransferMetadata\x12\x15google.protobuf.EmptyBq\n yandex.cloud.api.datatransfer.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1;datatransferb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,yandex_dot_cloud_dot_datatransfer_dot_v1_dot_transfer__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,])




_CREATETRANSFERREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.datatransfer.v1.CreateTransferRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.datatransfer.v1.CreateTransferRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.datatransfer.v1.CreateTransferRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=525,
  serialized_end=570,
)

_CREATETRANSFERREQUEST = _descriptor.Descriptor(
  name='CreateTransferRequest',
  full_name='yandex.cloud.datatransfer.v1.CreateTransferRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='source_id', full_name='yandex.cloud.datatransfer.v1.CreateTransferRequest.source_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_id', full_name='yandex.cloud.datatransfer.v1.CreateTransferRequest.target_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.datatransfer.v1.CreateTransferRequest.name', index=2,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.datatransfer.v1.CreateTransferRequest.description', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.datatransfer.v1.CreateTransferRequest.labels', index=4,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.datatransfer.v1.CreateTransferRequest.folder_id', index=5,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='yandex.cloud.datatransfer.v1.CreateTransferRequest.type', index=6,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATETRANSFERREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=269,
  serialized_end=570,
)


_CREATETRANSFERMETADATA = _descriptor.Descriptor(
  name='CreateTransferMetadata',
  full_name='yandex.cloud.datatransfer.v1.CreateTransferMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transfer_id', full_name='yandex.cloud.datatransfer.v1.CreateTransferMetadata.transfer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=572,
  serialized_end=617,
)


_UPDATETRANSFERREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.datatransfer.v1.UpdateTransferRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.datatransfer.v1.UpdateTransferRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.datatransfer.v1.UpdateTransferRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=525,
  serialized_end=570,
)

_UPDATETRANSFERREQUEST = _descriptor.Descriptor(
  name='UpdateTransferRequest',
  full_name='yandex.cloud.datatransfer.v1.UpdateTransferRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transfer_id', full_name='yandex.cloud.datatransfer.v1.UpdateTransferRequest.transfer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.datatransfer.v1.UpdateTransferRequest.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.datatransfer.v1.UpdateTransferRequest.labels', index=2,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.datatransfer.v1.UpdateTransferRequest.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.datatransfer.v1.UpdateTransferRequest.update_mask', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_UPDATETRANSFERREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=620,
  serialized_end=876,
)


_UPDATETRANSFERMETADATA = _descriptor.Descriptor(
  name='UpdateTransferMetadata',
  full_name='yandex.cloud.datatransfer.v1.UpdateTransferMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transfer_id', full_name='yandex.cloud.datatransfer.v1.UpdateTransferMetadata.transfer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=878,
  serialized_end=923,
)


_DELETETRANSFERREQUEST = _descriptor.Descriptor(
  name='DeleteTransferRequest',
  full_name='yandex.cloud.datatransfer.v1.DeleteTransferRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transfer_id', full_name='yandex.cloud.datatransfer.v1.DeleteTransferRequest.transfer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=925,
  serialized_end=969,
)


_DELETETRANSFERMETADATA = _descriptor.Descriptor(
  name='DeleteTransferMetadata',
  full_name='yandex.cloud.datatransfer.v1.DeleteTransferMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transfer_id', full_name='yandex.cloud.datatransfer.v1.DeleteTransferMetadata.transfer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=971,
  serialized_end=1016,
)


_LISTTRANSFERSREQUEST = _descriptor.Descriptor(
  name='ListTransfersRequest',
  full_name='yandex.cloud.datatransfer.v1.ListTransfersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.datatransfer.v1.ListTransfersRequest.folder_id', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.datatransfer.v1.ListTransfersRequest.page_size', index=1,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.datatransfer.v1.ListTransfersRequest.page_token', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1018,
  serialized_end=1098,
)


_LISTTRANSFERSRESPONSE = _descriptor.Descriptor(
  name='ListTransfersResponse',
  full_name='yandex.cloud.datatransfer.v1.ListTransfersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transfers', full_name='yandex.cloud.datatransfer.v1.ListTransfersResponse.transfers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.datatransfer.v1.ListTransfersResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1100,
  serialized_end=1207,
)


_GETTRANSFERREQUEST = _descriptor.Descriptor(
  name='GetTransferRequest',
  full_name='yandex.cloud.datatransfer.v1.GetTransferRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transfer_id', full_name='yandex.cloud.datatransfer.v1.GetTransferRequest.transfer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1209,
  serialized_end=1250,
)


_DEACTIVATETRANSFERREQUEST = _descriptor.Descriptor(
  name='DeactivateTransferRequest',
  full_name='yandex.cloud.datatransfer.v1.DeactivateTransferRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transfer_id', full_name='yandex.cloud.datatransfer.v1.DeactivateTransferRequest.transfer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1252,
  serialized_end=1300,
)


_DEACTIVATETRANSFERMETADATA = _descriptor.Descriptor(
  name='DeactivateTransferMetadata',
  full_name='yandex.cloud.datatransfer.v1.DeactivateTransferMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transfer_id', full_name='yandex.cloud.datatransfer.v1.DeactivateTransferMetadata.transfer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1302,
  serialized_end=1351,
)


_ACTIVATETRANSFERREQUEST = _descriptor.Descriptor(
  name='ActivateTransferRequest',
  full_name='yandex.cloud.datatransfer.v1.ActivateTransferRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transfer_id', full_name='yandex.cloud.datatransfer.v1.ActivateTransferRequest.transfer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1353,
  serialized_end=1399,
)


_ACTIVATETRANSFERMETADATA = _descriptor.Descriptor(
  name='ActivateTransferMetadata',
  full_name='yandex.cloud.datatransfer.v1.ActivateTransferMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transfer_id', full_name='yandex.cloud.datatransfer.v1.ActivateTransferMetadata.transfer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1401,
  serialized_end=1448,
)

_CREATETRANSFERREQUEST_LABELSENTRY.containing_type = _CREATETRANSFERREQUEST
_CREATETRANSFERREQUEST.fields_by_name['labels'].message_type = _CREATETRANSFERREQUEST_LABELSENTRY
_CREATETRANSFERREQUEST.fields_by_name['type'].enum_type = yandex_dot_cloud_dot_datatransfer_dot_v1_dot_transfer__pb2._TRANSFERTYPE
_UPDATETRANSFERREQUEST_LABELSENTRY.containing_type = _UPDATETRANSFERREQUEST
_UPDATETRANSFERREQUEST.fields_by_name['labels'].message_type = _UPDATETRANSFERREQUEST_LABELSENTRY
_UPDATETRANSFERREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_LISTTRANSFERSRESPONSE.fields_by_name['transfers'].message_type = yandex_dot_cloud_dot_datatransfer_dot_v1_dot_transfer__pb2._TRANSFER
DESCRIPTOR.message_types_by_name['CreateTransferRequest'] = _CREATETRANSFERREQUEST
DESCRIPTOR.message_types_by_name['CreateTransferMetadata'] = _CREATETRANSFERMETADATA
DESCRIPTOR.message_types_by_name['UpdateTransferRequest'] = _UPDATETRANSFERREQUEST
DESCRIPTOR.message_types_by_name['UpdateTransferMetadata'] = _UPDATETRANSFERMETADATA
DESCRIPTOR.message_types_by_name['DeleteTransferRequest'] = _DELETETRANSFERREQUEST
DESCRIPTOR.message_types_by_name['DeleteTransferMetadata'] = _DELETETRANSFERMETADATA
DESCRIPTOR.message_types_by_name['ListTransfersRequest'] = _LISTTRANSFERSREQUEST
DESCRIPTOR.message_types_by_name['ListTransfersResponse'] = _LISTTRANSFERSRESPONSE
DESCRIPTOR.message_types_by_name['GetTransferRequest'] = _GETTRANSFERREQUEST
DESCRIPTOR.message_types_by_name['DeactivateTransferRequest'] = _DEACTIVATETRANSFERREQUEST
DESCRIPTOR.message_types_by_name['DeactivateTransferMetadata'] = _DEACTIVATETRANSFERMETADATA
DESCRIPTOR.message_types_by_name['ActivateTransferRequest'] = _ACTIVATETRANSFERREQUEST
DESCRIPTOR.message_types_by_name['ActivateTransferMetadata'] = _ACTIVATETRANSFERMETADATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateTransferRequest = _reflection.GeneratedProtocolMessageType('CreateTransferRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATETRANSFERREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.datatransfer.v1.transfer_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.CreateTransferRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _CREATETRANSFERREQUEST,
  '__module__' : 'yandex.cloud.datatransfer.v1.transfer_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.CreateTransferRequest)
  })
_sym_db.RegisterMessage(CreateTransferRequest)
_sym_db.RegisterMessage(CreateTransferRequest.LabelsEntry)

CreateTransferMetadata = _reflection.GeneratedProtocolMessageType('CreateTransferMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATETRANSFERMETADATA,
  '__module__' : 'yandex.cloud.datatransfer.v1.transfer_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.CreateTransferMetadata)
  })
_sym_db.RegisterMessage(CreateTransferMetadata)

UpdateTransferRequest = _reflection.GeneratedProtocolMessageType('UpdateTransferRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATETRANSFERREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.datatransfer.v1.transfer_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.UpdateTransferRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATETRANSFERREQUEST,
  '__module__' : 'yandex.cloud.datatransfer.v1.transfer_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.UpdateTransferRequest)
  })
_sym_db.RegisterMessage(UpdateTransferRequest)
_sym_db.RegisterMessage(UpdateTransferRequest.LabelsEntry)

UpdateTransferMetadata = _reflection.GeneratedProtocolMessageType('UpdateTransferMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATETRANSFERMETADATA,
  '__module__' : 'yandex.cloud.datatransfer.v1.transfer_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.UpdateTransferMetadata)
  })
_sym_db.RegisterMessage(UpdateTransferMetadata)

DeleteTransferRequest = _reflection.GeneratedProtocolMessageType('DeleteTransferRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETETRANSFERREQUEST,
  '__module__' : 'yandex.cloud.datatransfer.v1.transfer_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.DeleteTransferRequest)
  })
_sym_db.RegisterMessage(DeleteTransferRequest)

DeleteTransferMetadata = _reflection.GeneratedProtocolMessageType('DeleteTransferMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETETRANSFERMETADATA,
  '__module__' : 'yandex.cloud.datatransfer.v1.transfer_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.DeleteTransferMetadata)
  })
_sym_db.RegisterMessage(DeleteTransferMetadata)

ListTransfersRequest = _reflection.GeneratedProtocolMessageType('ListTransfersRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTTRANSFERSREQUEST,
  '__module__' : 'yandex.cloud.datatransfer.v1.transfer_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.ListTransfersRequest)
  })
_sym_db.RegisterMessage(ListTransfersRequest)

ListTransfersResponse = _reflection.GeneratedProtocolMessageType('ListTransfersResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTTRANSFERSRESPONSE,
  '__module__' : 'yandex.cloud.datatransfer.v1.transfer_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.ListTransfersResponse)
  })
_sym_db.RegisterMessage(ListTransfersResponse)

GetTransferRequest = _reflection.GeneratedProtocolMessageType('GetTransferRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTRANSFERREQUEST,
  '__module__' : 'yandex.cloud.datatransfer.v1.transfer_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.GetTransferRequest)
  })
_sym_db.RegisterMessage(GetTransferRequest)

DeactivateTransferRequest = _reflection.GeneratedProtocolMessageType('DeactivateTransferRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEACTIVATETRANSFERREQUEST,
  '__module__' : 'yandex.cloud.datatransfer.v1.transfer_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.DeactivateTransferRequest)
  })
_sym_db.RegisterMessage(DeactivateTransferRequest)

DeactivateTransferMetadata = _reflection.GeneratedProtocolMessageType('DeactivateTransferMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DEACTIVATETRANSFERMETADATA,
  '__module__' : 'yandex.cloud.datatransfer.v1.transfer_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.DeactivateTransferMetadata)
  })
_sym_db.RegisterMessage(DeactivateTransferMetadata)

ActivateTransferRequest = _reflection.GeneratedProtocolMessageType('ActivateTransferRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVATETRANSFERREQUEST,
  '__module__' : 'yandex.cloud.datatransfer.v1.transfer_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.ActivateTransferRequest)
  })
_sym_db.RegisterMessage(ActivateTransferRequest)

ActivateTransferMetadata = _reflection.GeneratedProtocolMessageType('ActivateTransferMetadata', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVATETRANSFERMETADATA,
  '__module__' : 'yandex.cloud.datatransfer.v1.transfer_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.ActivateTransferMetadata)
  })
_sym_db.RegisterMessage(ActivateTransferMetadata)


DESCRIPTOR._options = None
_CREATETRANSFERREQUEST_LABELSENTRY._options = None
_UPDATETRANSFERREQUEST_LABELSENTRY._options = None

_TRANSFERSERVICE = _descriptor.ServiceDescriptor(
  name='TransferService',
  full_name='yandex.cloud.datatransfer.v1.TransferService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1451,
  serialized_end=2696,
  methods=[
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.datatransfer.v1.TransferService.Create',
    index=0,
    containing_service=None,
    input_type=_CREATETRANSFERREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\021\"\014/v1/transfer:\001*\262\322*\"\n\026CreateTransferMetadata\022\010Transfer',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.datatransfer.v1.TransferService.Update',
    index=1,
    containing_service=None,
    input_type=_UPDATETRANSFERREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\0372\032/v1/transfer/{transfer_id}:\001*\262\322*\"\n\026UpdateTransferMetadata\022\010Transfer',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.datatransfer.v1.TransferService.Delete',
    index=2,
    containing_service=None,
    input_type=_DELETETRANSFERREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\034*\032/v1/transfer/{transfer_id}\262\322*/\n\026DeleteTransferMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.datatransfer.v1.TransferService.List',
    index=3,
    containing_service=None,
    input_type=_LISTTRANSFERSREQUEST,
    output_type=_LISTTRANSFERSRESPONSE,
    serialized_options=b'\202\323\344\223\002 \022\036/v1/transfers/list/{folder_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.datatransfer.v1.TransferService.Get',
    index=4,
    containing_service=None,
    input_type=_GETTRANSFERREQUEST,
    output_type=yandex_dot_cloud_dot_datatransfer_dot_v1_dot_transfer__pb2._TRANSFER,
    serialized_options=b'\202\323\344\223\002\034\022\032/v1/transfer/{transfer_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Deactivate',
    full_name='yandex.cloud.datatransfer.v1.TransferService.Deactivate',
    index=5,
    containing_service=None,
    input_type=_DEACTIVATETRANSFERREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002*\"%/v1/transfer/{transfer_id}:deactivate:\001*\262\322*3\n\032DeactivateTransferMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Activate',
    full_name='yandex.cloud.datatransfer.v1.TransferService.Activate',
    index=6,
    containing_service=None,
    input_type=_ACTIVATETRANSFERREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002(\"#/v1/transfer/{transfer_id}:activate:\001*\262\322*1\n\030ActivateTransferMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TRANSFERSERVICE)

DESCRIPTOR.services_by_name['TransferService'] = _TRANSFERSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/serverless/mdbproxy/v1/proxy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/serverless/mdbproxy/v1/proxy.proto',
  package='yandex.cloud.serverless.mdbproxy.v1',
  syntax='proto3',
  serialized_options=b'\n\'yandex.cloud.api.serverless.mdbproxy.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/mdbproxy/v1;proxy',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n/yandex/cloud/serverless/mdbproxy/v1/proxy.proto\x12#yandex.cloud.serverless.mdbproxy.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\xac\x03\n\x05Proxy\x12\n\n\x02id\x18\x01 \x01(\t\x12\x1f\n\tfolder_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x33\n\x04name\x18\x04 \x01(\tB%\xe8\xc7\x31\x01\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x8f\x01\n\x06labels\x18\x06 \x03(\x0b\x32\x36.yandex.cloud.serverless.mdbproxy.v1.Proxy.LabelsEntryBG\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x16\x12\x14[a-z][-_./\\@0-9a-z]*\x12;\n\x06target\x18\x07 \x01(\x0b\x32+.yandex.cloud.serverless.mdbproxy.v1.Target\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8e\x04\n\x06Target\x12L\n\nclickhouse\x18\x01 \x01(\x0b\x32\x36.yandex.cloud.serverless.mdbproxy.v1.Target.ClickHouseH\x00\x12L\n\npostgresql\x18\x02 \x01(\x0b\x32\x36.yandex.cloud.serverless.mdbproxy.v1.Target.PostgreSQLH\x00\x1a\xac\x01\n\nPostgreSQL\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12,\n\x04user\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x12\x10\n\x08password\x18\x03 \x01(\t\x12*\n\x02\x64\x62\x18\x04 \x01(\tB\x1e\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x12\x10\n\x08\x65ndpoint\x18\x05 \x01(\t\x1a\xab\x01\n\nClickHouse\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12+\n\x04user\x18\x02 \x01(\tB\x1d\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=63\xf2\xc7\x31\r[a-zA-Z0-9_]*\x12\x10\n\x08password\x18\x03 \x01(\t\x12*\n\x02\x64\x62\x18\x04 \x01(\tB\x1e\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x12\x10\n\x08\x65ndpoint\x18\x05 \x01(\tB\x0b\n\x03mdb\x12\x04\xc0\xc1\x31\x01\x42x\n\'yandex.cloud.api.serverless.mdbproxy.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/mdbproxy/v1;proxyb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_PROXY_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.serverless.mdbproxy.v1.Proxy.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.serverless.mdbproxy.v1.Proxy.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.serverless.mdbproxy.v1.Proxy.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=536,
  serialized_end=581,
)

_PROXY = _descriptor.Descriptor(
  name='Proxy',
  full_name='yandex.cloud.serverless.mdbproxy.v1.Proxy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.serverless.mdbproxy.v1.Proxy.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.serverless.mdbproxy.v1.Proxy.folder_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='yandex.cloud.serverless.mdbproxy.v1.Proxy.created_at', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.serverless.mdbproxy.v1.Proxy.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.serverless.mdbproxy.v1.Proxy.description', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.serverless.mdbproxy.v1.Proxy.labels', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\017[-_./\\@0-9a-z]*\262\3101\006\032\0041-63\262\3101\026\022\024[a-z][-_./\\@0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target', full_name='yandex.cloud.serverless.mdbproxy.v1.Proxy.target', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PROXY_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=153,
  serialized_end=581,
)


_TARGET_POSTGRESQL = _descriptor.Descriptor(
  name='PostgreSQL',
  full_name='yandex.cloud.serverless.mdbproxy.v1.Target.PostgreSQL',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.serverless.mdbproxy.v1.Target.PostgreSQL.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user', full_name='yandex.cloud.serverless.mdbproxy.v1.Target.PostgreSQL.user', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=63\362\3071\016[a-zA-Z0-9_-]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='yandex.cloud.serverless.mdbproxy.v1.Target.PostgreSQL.password', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='db', full_name='yandex.cloud.serverless.mdbproxy.v1.Target.PostgreSQL.db', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=63\362\3071\016[a-zA-Z0-9_-]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='endpoint', full_name='yandex.cloud.serverless.mdbproxy.v1.Target.PostgreSQL.endpoint', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=751,
  serialized_end=923,
)

_TARGET_CLICKHOUSE = _descriptor.Descriptor(
  name='ClickHouse',
  full_name='yandex.cloud.serverless.mdbproxy.v1.Target.ClickHouse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.serverless.mdbproxy.v1.Target.ClickHouse.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user', full_name='yandex.cloud.serverless.mdbproxy.v1.Target.ClickHouse.user', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=63\362\3071\r[a-zA-Z0-9_]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='yandex.cloud.serverless.mdbproxy.v1.Target.ClickHouse.password', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='db', full_name='yandex.cloud.serverless.mdbproxy.v1.Target.ClickHouse.db', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=63\362\3071\016[a-zA-Z0-9_-]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='endpoint', full_name='yandex.cloud.serverless.mdbproxy.v1.Target.ClickHouse.endpoint', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=926,
  serialized_end=1097,
)

_TARGET = _descriptor.Descriptor(
  name='Target',
  full_name='yandex.cloud.serverless.mdbproxy.v1.Target',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='clickhouse', full_name='yandex.cloud.serverless.mdbproxy.v1.Target.clickhouse', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='postgresql', full_name='yandex.cloud.serverless.mdbproxy.v1.Target.postgresql', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TARGET_POSTGRESQL, _TARGET_CLICKHOUSE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='mdb', full_name='yandex.cloud.serverless.mdbproxy.v1.Target.mdb',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=584,
  serialized_end=1110,
)

_PROXY_LABELSENTRY.containing_type = _PROXY
_PROXY.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PROXY.fields_by_name['labels'].message_type = _PROXY_LABELSENTRY
_PROXY.fields_by_name['target'].message_type = _TARGET
_TARGET_POSTGRESQL.containing_type = _TARGET
_TARGET_CLICKHOUSE.containing_type = _TARGET
_TARGET.fields_by_name['clickhouse'].message_type = _TARGET_CLICKHOUSE
_TARGET.fields_by_name['postgresql'].message_type = _TARGET_POSTGRESQL
_TARGET.oneofs_by_name['mdb'].fields.append(
  _TARGET.fields_by_name['clickhouse'])
_TARGET.fields_by_name['clickhouse'].containing_oneof = _TARGET.oneofs_by_name['mdb']
_TARGET.oneofs_by_name['mdb'].fields.append(
  _TARGET.fields_by_name['postgresql'])
_TARGET.fields_by_name['postgresql'].containing_oneof = _TARGET.oneofs_by_name['mdb']
DESCRIPTOR.message_types_by_name['Proxy'] = _PROXY
DESCRIPTOR.message_types_by_name['Target'] = _TARGET
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Proxy = _reflection.GeneratedProtocolMessageType('Proxy', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _PROXY_LABELSENTRY,
    '__module__' : 'yandex.cloud.serverless.mdbproxy.v1.proxy_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.mdbproxy.v1.Proxy.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _PROXY,
  '__module__' : 'yandex.cloud.serverless.mdbproxy.v1.proxy_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.mdbproxy.v1.Proxy)
  })
_sym_db.RegisterMessage(Proxy)
_sym_db.RegisterMessage(Proxy.LabelsEntry)

Target = _reflection.GeneratedProtocolMessageType('Target', (_message.Message,), {

  'PostgreSQL' : _reflection.GeneratedProtocolMessageType('PostgreSQL', (_message.Message,), {
    'DESCRIPTOR' : _TARGET_POSTGRESQL,
    '__module__' : 'yandex.cloud.serverless.mdbproxy.v1.proxy_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.mdbproxy.v1.Target.PostgreSQL)
    })
  ,

  'ClickHouse' : _reflection.GeneratedProtocolMessageType('ClickHouse', (_message.Message,), {
    'DESCRIPTOR' : _TARGET_CLICKHOUSE,
    '__module__' : 'yandex.cloud.serverless.mdbproxy.v1.proxy_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.mdbproxy.v1.Target.ClickHouse)
    })
  ,
  'DESCRIPTOR' : _TARGET,
  '__module__' : 'yandex.cloud.serverless.mdbproxy.v1.proxy_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.mdbproxy.v1.Target)
  })
_sym_db.RegisterMessage(Target)
_sym_db.RegisterMessage(Target.PostgreSQL)
_sym_db.RegisterMessage(Target.ClickHouse)


DESCRIPTOR._options = None
_PROXY_LABELSENTRY._options = None
_PROXY.fields_by_name['folder_id']._options = None
_PROXY.fields_by_name['name']._options = None
_PROXY.fields_by_name['labels']._options = None
_TARGET_POSTGRESQL.fields_by_name['cluster_id']._options = None
_TARGET_POSTGRESQL.fields_by_name['user']._options = None
_TARGET_POSTGRESQL.fields_by_name['db']._options = None
_TARGET_CLICKHOUSE.fields_by_name['cluster_id']._options = None
_TARGET_CLICKHOUSE.fields_by_name['user']._options = None
_TARGET_CLICKHOUSE.fields_by_name['db']._options = None
_TARGET.oneofs_by_name['mdb']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/billing/v1/budget_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.billing.v1 import budget_pb2 as yandex_dot_cloud_dot_billing_dot_v1_dot_budget__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/billing/v1/budget_service.proto',
  package='yandex.cloud.billing.v1',
  syntax='proto3',
  serialized_options=b'\n\033yandex.cloud.api.billing.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/v1;billing',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n,yandex/cloud/billing/v1/budget_service.proto\x12\x17yandex.cloud.billing.v1\x1a\x1cgoogle/api/annotations.proto\x1a$yandex/cloud/billing/v1/budget.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\",\n\x10GetBudgetRequest\x12\x18\n\x02id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"|\n\x12ListBudgetsRequest\x12(\n\x12\x62illing_account_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"`\n\x13ListBudgetsResponse\x12\x30\n\x07\x62udgets\x18\x01 \x03(\x0b\x32\x1f.yandex.cloud.billing.v1.Budget\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xc3\x02\n\x13\x43reateBudgetRequest\x12(\n\x12\x62illing_account_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x12\n\x04name\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x43\n\x10\x63ost_budget_spec\x18\x03 \x01(\x0b\x32\'.yandex.cloud.billing.v1.CostBudgetSpecH\x00\x12I\n\x13\x65xpense_budget_spec\x18\x04 \x01(\x0b\x32*.yandex.cloud.billing.v1.ExpenseBudgetSpecH\x00\x12I\n\x13\x62\x61lance_budget_spec\x18\x05 \x01(\x0b\x32*.yandex.cloud.billing.v1.BalanceBudgetSpecH\x00\x42\x13\n\x0b\x62udget_spec\x12\x04\xc0\xc1\x31\x01\")\n\x14\x43reateBudgetMetadata\x12\x11\n\tbudget_id\x18\x01 \x01(\t2\xa2\x03\n\rBudgetService\x12s\n\x03Get\x12).yandex.cloud.billing.v1.GetBudgetRequest\x1a\x1f.yandex.cloud.billing.v1.Budget\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/billing/v1/budgets/{id}\x12~\n\x04List\x12+.yandex.cloud.billing.v1.ListBudgetsRequest\x1a,.yandex.cloud.billing.v1.ListBudgetsResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/billing/v1/budgets\x12\x9b\x01\n\x06\x43reate\x12,.yandex.cloud.billing.v1.CreateBudgetRequest\x1a!.yandex.cloud.operation.Operation\"@\x82\xd3\xe4\x93\x02\x18\"\x13/billing/v1/budgets:\x01*\xb2\xd2*\x1e\n\x14\x43reateBudgetMetadata\x12\x06\x42udgetBb\n\x1byandex.cloud.api.billing.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/v1;billingb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,yandex_dot_cloud_dot_billing_dot_v1_dot_budget__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_GETBUDGETREQUEST = _descriptor.Descriptor(
  name='GetBudgetRequest',
  full_name='yandex.cloud.billing.v1.GetBudgetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.billing.v1.GetBudgetRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=246,
  serialized_end=290,
)


_LISTBUDGETSREQUEST = _descriptor.Descriptor(
  name='ListBudgetsRequest',
  full_name='yandex.cloud.billing.v1.ListBudgetsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='billing_account_id', full_name='yandex.cloud.billing.v1.ListBudgetsRequest.billing_account_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.billing.v1.ListBudgetsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.billing.v1.ListBudgetsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=292,
  serialized_end=416,
)


_LISTBUDGETSRESPONSE = _descriptor.Descriptor(
  name='ListBudgetsResponse',
  full_name='yandex.cloud.billing.v1.ListBudgetsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='budgets', full_name='yandex.cloud.billing.v1.ListBudgetsResponse.budgets', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.billing.v1.ListBudgetsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=418,
  serialized_end=514,
)


_CREATEBUDGETREQUEST = _descriptor.Descriptor(
  name='CreateBudgetRequest',
  full_name='yandex.cloud.billing.v1.CreateBudgetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='billing_account_id', full_name='yandex.cloud.billing.v1.CreateBudgetRequest.billing_account_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.billing.v1.CreateBudgetRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cost_budget_spec', full_name='yandex.cloud.billing.v1.CreateBudgetRequest.cost_budget_spec', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expense_budget_spec', full_name='yandex.cloud.billing.v1.CreateBudgetRequest.expense_budget_spec', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='balance_budget_spec', full_name='yandex.cloud.billing.v1.CreateBudgetRequest.balance_budget_spec', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='budget_spec', full_name='yandex.cloud.billing.v1.CreateBudgetRequest.budget_spec',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=517,
  serialized_end=840,
)


_CREATEBUDGETMETADATA = _descriptor.Descriptor(
  name='CreateBudgetMetadata',
  full_name='yandex.cloud.billing.v1.CreateBudgetMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='budget_id', full_name='yandex.cloud.billing.v1.CreateBudgetMetadata.budget_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=842,
  serialized_end=883,
)

_LISTBUDGETSRESPONSE.fields_by_name['budgets'].message_type = yandex_dot_cloud_dot_billing_dot_v1_dot_budget__pb2._BUDGET
_CREATEBUDGETREQUEST.fields_by_name['cost_budget_spec'].message_type = yandex_dot_cloud_dot_billing_dot_v1_dot_budget__pb2._COSTBUDGETSPEC
_CREATEBUDGETREQUEST.fields_by_name['expense_budget_spec'].message_type = yandex_dot_cloud_dot_billing_dot_v1_dot_budget__pb2._EXPENSEBUDGETSPEC
_CREATEBUDGETREQUEST.fields_by_name['balance_budget_spec'].message_type = yandex_dot_cloud_dot_billing_dot_v1_dot_budget__pb2._BALANCEBUDGETSPEC
_CREATEBUDGETREQUEST.oneofs_by_name['budget_spec'].fields.append(
  _CREATEBUDGETREQUEST.fields_by_name['cost_budget_spec'])
_CREATEBUDGETREQUEST.fields_by_name['cost_budget_spec'].containing_oneof = _CREATEBUDGETREQUEST.oneofs_by_name['budget_spec']
_CREATEBUDGETREQUEST.oneofs_by_name['budget_spec'].fields.append(
  _CREATEBUDGETREQUEST.fields_by_name['expense_budget_spec'])
_CREATEBUDGETREQUEST.fields_by_name['expense_budget_spec'].containing_oneof = _CREATEBUDGETREQUEST.oneofs_by_name['budget_spec']
_CREATEBUDGETREQUEST.oneofs_by_name['budget_spec'].fields.append(
  _CREATEBUDGETREQUEST.fields_by_name['balance_budget_spec'])
_CREATEBUDGETREQUEST.fields_by_name['balance_budget_spec'].containing_oneof = _CREATEBUDGETREQUEST.oneofs_by_name['budget_spec']
DESCRIPTOR.message_types_by_name['GetBudgetRequest'] = _GETBUDGETREQUEST
DESCRIPTOR.message_types_by_name['ListBudgetsRequest'] = _LISTBUDGETSREQUEST
DESCRIPTOR.message_types_by_name['ListBudgetsResponse'] = _LISTBUDGETSRESPONSE
DESCRIPTOR.message_types_by_name['CreateBudgetRequest'] = _CREATEBUDGETREQUEST
DESCRIPTOR.message_types_by_name['CreateBudgetMetadata'] = _CREATEBUDGETMETADATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetBudgetRequest = _reflection.GeneratedProtocolMessageType('GetBudgetRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBUDGETREQUEST,
  '__module__' : 'yandex.cloud.billing.v1.budget_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.billing.v1.GetBudgetRequest)
  })
_sym_db.RegisterMessage(GetBudgetRequest)

ListBudgetsRequest = _reflection.GeneratedProtocolMessageType('ListBudgetsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTBUDGETSREQUEST,
  '__module__' : 'yandex.cloud.billing.v1.budget_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.billing.v1.ListBudgetsRequest)
  })
_sym_db.RegisterMessage(ListBudgetsRequest)

ListBudgetsResponse = _reflection.GeneratedProtocolMessageType('ListBudgetsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTBUDGETSRESPONSE,
  '__module__' : 'yandex.cloud.billing.v1.budget_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.billing.v1.ListBudgetsResponse)
  })
_sym_db.RegisterMessage(ListBudgetsResponse)

CreateBudgetRequest = _reflection.GeneratedProtocolMessageType('CreateBudgetRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEBUDGETREQUEST,
  '__module__' : 'yandex.cloud.billing.v1.budget_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.billing.v1.CreateBudgetRequest)
  })
_sym_db.RegisterMessage(CreateBudgetRequest)

CreateBudgetMetadata = _reflection.GeneratedProtocolMessageType('CreateBudgetMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATEBUDGETMETADATA,
  '__module__' : 'yandex.cloud.billing.v1.budget_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.billing.v1.CreateBudgetMetadata)
  })
_sym_db.RegisterMessage(CreateBudgetMetadata)


DESCRIPTOR._options = None
_GETBUDGETREQUEST.fields_by_name['id']._options = None
_LISTBUDGETSREQUEST.fields_by_name['billing_account_id']._options = None
_LISTBUDGETSREQUEST.fields_by_name['page_size']._options = None
_LISTBUDGETSREQUEST.fields_by_name['page_token']._options = None
_CREATEBUDGETREQUEST.oneofs_by_name['budget_spec']._options = None
_CREATEBUDGETREQUEST.fields_by_name['billing_account_id']._options = None
_CREATEBUDGETREQUEST.fields_by_name['name']._options = None

_BUDGETSERVICE = _descriptor.ServiceDescriptor(
  name='BudgetService',
  full_name='yandex.cloud.billing.v1.BudgetService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=886,
  serialized_end=1304,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.billing.v1.BudgetService.Get',
    index=0,
    containing_service=None,
    input_type=_GETBUDGETREQUEST,
    output_type=yandex_dot_cloud_dot_billing_dot_v1_dot_budget__pb2._BUDGET,
    serialized_options=b'\202\323\344\223\002\032\022\030/billing/v1/budgets/{id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.billing.v1.BudgetService.List',
    index=1,
    containing_service=None,
    input_type=_LISTBUDGETSREQUEST,
    output_type=_LISTBUDGETSRESPONSE,
    serialized_options=b'\202\323\344\223\002\025\022\023/billing/v1/budgets',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.billing.v1.BudgetService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATEBUDGETREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\030\"\023/billing/v1/budgets:\001*\262\322*\036\n\024CreateBudgetMetadata\022\006Budget',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_BUDGETSERVICE)

DESCRIPTOR.services_by_name['BudgetService'] = _BUDGETSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/billing/v1/sku_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.billing.v1 import sku_pb2 as yandex_dot_cloud_dot_billing_dot_v1_dot_sku__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/billing/v1/sku_service.proto',
  package='yandex.cloud.billing.v1',
  syntax='proto3',
  serialized_options=b'\n\033yandex.cloud.api.billing.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/v1;billing',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)yandex/cloud/billing/v1/sku_service.proto\x12\x17yandex.cloud.billing.v1\x1a\x1cgoogle/api/annotations.proto\x1a!yandex/cloud/billing/v1/sku.proto\x1a\x1dyandex/cloud/validation.proto\"]\n\rGetSkuRequest\x12\x18\n\x02id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x16\n\x08\x63urrency\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1a\n\x12\x62illing_account_id\x18\x03 \x01(\t\"\x9f\x01\n\x0fListSkusRequest\x12\x16\n\x08\x63urrency\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1a\n\x12\x62illing_account_id\x18\x02 \x01(\t\x12\x1a\n\x06\x66ilter\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x1d\n\tpage_size\x18\x04 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05<=100\"W\n\x10ListSkusResponse\x12*\n\x04skus\x18\x01 \x03(\x0b\x32\x1c.yandex.cloud.billing.v1.Sku\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xef\x01\n\nSkuService\x12j\n\x03Get\x12&.yandex.cloud.billing.v1.GetSkuRequest\x1a\x1c.yandex.cloud.billing.v1.Sku\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/billing/v1/skus/{id}\x12u\n\x04List\x12(.yandex.cloud.billing.v1.ListSkusRequest\x1a).yandex.cloud.billing.v1.ListSkusResponse\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/billing/v1/skusBb\n\x1byandex.cloud.api.billing.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/v1;billingb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,yandex_dot_cloud_dot_billing_dot_v1_dot_sku__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_GETSKUREQUEST = _descriptor.Descriptor(
  name='GetSkuRequest',
  full_name='yandex.cloud.billing.v1.GetSkuRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.billing.v1.GetSkuRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='currency', full_name='yandex.cloud.billing.v1.GetSkuRequest.currency', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='billing_account_id', full_name='yandex.cloud.billing.v1.GetSkuRequest.billing_account_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=166,
  serialized_end=259,
)


_LISTSKUSREQUEST = _descriptor.Descriptor(
  name='ListSkusRequest',
  full_name='yandex.cloud.billing.v1.ListSkusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='currency', full_name='yandex.cloud.billing.v1.ListSkusRequest.currency', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='billing_account_id', full_name='yandex.cloud.billing.v1.ListSkusRequest.billing_account_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.billing.v1.ListSkusRequest.filter', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.billing.v1.ListSkusRequest.page_size', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.billing.v1.ListSkusRequest.page_token', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=262,
  serialized_end=421,
)


_LISTSKUSRESPONSE = _descriptor.Descriptor(
  name='ListSkusResponse',
  full_name='yandex.cloud.billing.v1.ListSkusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='skus', full_name='yandex.cloud.billing.v1.ListSkusResponse.skus', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.billing.v1.ListSkusResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=423,
  serialized_end=510,
)

_LISTSKUSRESPONSE.fields_by_name['skus'].message_type = yandex_dot_cloud_dot_billing_dot_v1_dot_sku__pb2._SKU
DESCRIPTOR.message_types_by_name['GetSkuRequest'] = _GETSKUREQUEST
DESCRIPTOR.message_types_by_name['ListSkusRequest'] = _LISTSKUSREQUEST
DESCRIPTOR.message_types_by_name['ListSkusResponse'] = _LISTSKUSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetSkuRequest = _reflection.GeneratedProtocolMessageType('GetSkuRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSKUREQUEST,
  '__module__' : 'yandex.cloud.billing.v1.sku_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.billing.v1.GetSkuRequest)
  })
_sym_db.RegisterMessage(GetSkuRequest)

ListSkusRequest = _reflection.GeneratedProtocolMessageType('ListSkusRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSKUSREQUEST,
  '__module__' : 'yandex.cloud.billing.v1.sku_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.billing.v1.ListSkusRequest)
  })
_sym_db.RegisterMessage(ListSkusRequest)

ListSkusResponse = _reflection.GeneratedProtocolMessageType('ListSkusResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSKUSRESPONSE,
  '__module__' : 'yandex.cloud.billing.v1.sku_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.billing.v1.ListSkusResponse)
  })
_sym_db.RegisterMessage(ListSkusResponse)


DESCRIPTOR._options = None
_GETSKUREQUEST.fields_by_name['id']._options = None
_GETSKUREQUEST.fields_by_name['currency']._options = None
_LISTSKUSREQUEST.fields_by_name['currency']._options = None
_LISTSKUSREQUEST.fields_by_name['filter']._options = None
_LISTSKUSREQUEST.fields_by_name['page_size']._options = None
_LISTSKUSREQUEST.fields_by_name['page_token']._options = None

_SKUSERVICE = _descriptor.ServiceDescriptor(
  name='SkuService',
  full_name='yandex.cloud.billing.v1.SkuService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=513,
  serialized_end=752,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.billing.v1.SkuService.Get',
    index=0,
    containing_service=None,
    input_type=_GETSKUREQUEST,
    output_type=yandex_dot_cloud_dot_billing_dot_v1_dot_sku__pb2._SKU,
    serialized_options=b'\202\323\344\223\002\027\022\025/billing/v1/skus/{id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.billing.v1.SkuService.List',
    index=1,
    containing_service=None,
    input_type=_LISTSKUSREQUEST,
    output_type=_LISTSKUSRESPONSE,
    serialized_options=b'\202\323\344\223\002\022\022\020/billing/v1/skus',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SKUSERVICE)

DESCRIPTOR.services_by_name['SkuService'] = _SKUSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/billing/v1/billing_account_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.billing.v1 import billing_account_pb2 as yandex_dot_cloud_dot_billing_dot_v1_dot_billing__account__pb2
from yandex.cloud.billing.v1 import billable_object_pb2 as yandex_dot_cloud_dot_billing_dot_v1_dot_billable__object__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/billing/v1/billing_account_service.proto',
  package='yandex.cloud.billing.v1',
  syntax='proto3',
  serialized_options=b'\n\033yandex.cloud.api.billing.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/v1;billing',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n5yandex/cloud/billing/v1/billing_account_service.proto\x12\x17yandex.cloud.billing.v1\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/access/access.proto\x1a-yandex/cloud/billing/v1/billing_account.proto\x1a-yandex/cloud/billing/v1/billable_object.proto\x1a&yandex/cloud/operation/operation.proto\x1a yandex/cloud/api/operation.proto\x1a\x1dyandex/cloud/validation.proto\"4\n\x18GetBillingAccountRequest\x12\x18\n\x02id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"Z\n\x1aListBillingAccountsRequest\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"y\n\x1bListBillingAccountsResponse\x12\x41\n\x10\x62illing_accounts\x18\x01 \x03(\x0b\x32\'.yandex.cloud.billing.v1.BillingAccount\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x8b\x01\n!ListBillableObjectBindingsRequest\x12(\n\x12\x62illing_account_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"\x8f\x01\n\"ListBillableObjectBindingsResponse\x12P\n\x18\x62illable_object_bindings\x18\x01 \x03(\x0b\x32..yandex.cloud.billing.v1.BillableObjectBinding\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x87\x01\n\x19\x42indBillableObjectRequest\x12(\n\x12\x62illing_account_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12@\n\x0f\x62illable_object\x18\x02 \x01(\x0b\x32\'.yandex.cloud.billing.v1.BillableObject\"8\n\x1a\x42indBillableObjectMetadata\x12\x1a\n\x12\x62illable_object_id\x18\x01 \x01(\t2\xd9\t\n\x15\x42illingAccountService\x12\x8b\x01\n\x03Get\x12\x31.yandex.cloud.billing.v1.GetBillingAccountRequest\x1a\'.yandex.cloud.billing.v1.BillingAccount\"(\x82\xd3\xe4\x93\x02\"\x12 /billing/v1/billingAccounts/{id}\x12\x96\x01\n\x04List\x12\x33.yandex.cloud.billing.v1.ListBillingAccountsRequest\x1a\x34.yandex.cloud.billing.v1.ListBillingAccountsResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/billing/v1/billingAccounts\x12\xe6\x01\n\x1aListBillableObjectBindings\x12:.yandex.cloud.billing.v1.ListBillableObjectBindingsRequest\x1a;.yandex.cloud.billing.v1.ListBillableObjectBindingsResponse\"O\x82\xd3\xe4\x93\x02I\x12G/billing/v1/billingAccounts/{billing_account_id}/billableObjectBindings\x12\xf7\x01\n\x12\x42indBillableObject\x12\x32.yandex.cloud.billing.v1.BindBillableObjectRequest\x1a!.yandex.cloud.operation.Operation\"\x89\x01\x82\xd3\xe4\x93\x02L\"G/billing/v1/billingAccounts/{billing_account_id}/billableObjectBindings:\x01*\xb2\xd2*3\n\x1a\x42indBillableObjectMetadata\x12\x15\x42illableObjectBinding\x12\xbb\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\"D\x82\xd3\xe4\x93\x02>\x12</billing/v1/billingAccounts/{resource_id}:listAccessBindings\x12\xf7\x01\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x89\x01\x82\xd3\xe4\x93\x02\x43\x32>/billing/v1/billingAccounts/{resource_id}:updateAccessBindings:\x01*\xb2\xd2*<\n#access.UpdateAccessBindingsMetadata\x12\x15google.protobuf.EmptyBb\n\x1byandex.cloud.api.billing.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/v1;billingb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,yandex_dot_cloud_dot_access_dot_access__pb2.DESCRIPTOR,yandex_dot_cloud_dot_billing_dot_v1_dot_billing__account__pb2.DESCRIPTOR,yandex_dot_cloud_dot_billing_dot_v1_dot_billable__object__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_GETBILLINGACCOUNTREQUEST = _descriptor.Descriptor(
  name='GetBillingAccountRequest',
  full_name='yandex.cloud.billing.v1.GetBillingAccountRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.billing.v1.GetBillingAccountRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=345,
  serialized_end=397,
)


_LISTBILLINGACCOUNTSREQUEST = _descriptor.Descriptor(
  name='ListBillingAccountsRequest',
  full_name='yandex.cloud.billing.v1.ListBillingAccountsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.billing.v1.ListBillingAccountsRequest.page_size', index=0,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.billing.v1.ListBillingAccountsRequest.page_token', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=399,
  serialized_end=489,
)


_LISTBILLINGACCOUNTSRESPONSE = _descriptor.Descriptor(
  name='ListBillingAccountsResponse',
  full_name='yandex.cloud.billing.v1.ListBillingAccountsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='billing_accounts', full_name='yandex.cloud.billing.v1.ListBillingAccountsResponse.billing_accounts', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.billing.v1.ListBillingAccountsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=491,
  serialized_end=612,
)


_LISTBILLABLEOBJECTBINDINGSREQUEST = _descriptor.Descriptor(
  name='ListBillableObjectBindingsRequest',
  full_name='yandex.cloud.billing.v1.ListBillableObjectBindingsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='billing_account_id', full_name='yandex.cloud.billing.v1.ListBillableObjectBindingsRequest.billing_account_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.billing.v1.ListBillableObjectBindingsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.billing.v1.ListBillableObjectBindingsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=615,
  serialized_end=754,
)


_LISTBILLABLEOBJECTBINDINGSRESPONSE = _descriptor.Descriptor(
  name='ListBillableObjectBindingsResponse',
  full_name='yandex.cloud.billing.v1.ListBillableObjectBindingsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='billable_object_bindings', full_name='yandex.cloud.billing.v1.ListBillableObjectBindingsResponse.billable_object_bindings', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.billing.v1.ListBillableObjectBindingsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=757,
  serialized_end=900,
)


_BINDBILLABLEOBJECTREQUEST = _descriptor.Descriptor(
  name='BindBillableObjectRequest',
  full_name='yandex.cloud.billing.v1.BindBillableObjectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='billing_account_id', full_name='yandex.cloud.billing.v1.BindBillableObjectRequest.billing_account_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='billable_object', full_name='yandex.cloud.billing.v1.BindBillableObjectRequest.billable_object', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=903,
  serialized_end=1038,
)


_BINDBILLABLEOBJECTMETADATA = _descriptor.Descriptor(
  name='BindBillableObjectMetadata',
  full_name='yandex.cloud.billing.v1.BindBillableObjectMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='billable_object_id', full_name='yandex.cloud.billing.v1.BindBillableObjectMetadata.billable_object_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1040,
  serialized_end=1096,
)

_LISTBILLINGACCOUNTSRESPONSE.fields_by_name['billing_accounts'].message_type = yandex_dot_cloud_dot_billing_dot_v1_dot_billing__account__pb2._BILLINGACCOUNT
_LISTBILLABLEOBJECTBINDINGSRESPONSE.fields_by_name['billable_object_bindings'].message_type = yandex_dot_cloud_dot_billing_dot_v1_dot_billable__object__pb2._BILLABLEOBJECTBINDING
_BINDBILLABLEOBJECTREQUEST.fields_by_name['billable_object'].message_type = yandex_dot_cloud_dot_billing_dot_v1_dot_billable__object__pb2._BILLABLEOBJECT
DESCRIPTOR.message_types_by_name['GetBillingAccountRequest'] = _GETBILLINGACCOUNTREQUEST
DESCRIPTOR.message_types_by_name['ListBillingAccountsRequest'] = _LISTBILLINGACCOUNTSREQUEST
DESCRIPTOR.message_types_by_name['ListBillingAccountsResponse'] = _LISTBILLINGACCOUNTSRESPONSE
DESCRIPTOR.message_types_by_name['ListBillableObjectBindingsRequest'] = _LISTBILLABLEOBJECTBINDINGSREQUEST
DESCRIPTOR.message_types_by_name['ListBillableObjectBindingsResponse'] = _LISTBILLABLEOBJECTBINDINGSRESPONSE
DESCRIPTOR.message_types_by_name['BindBillableObjectRequest'] = _BINDBILLABLEOBJECTREQUEST
DESCRIPTOR.message_types_by_name['BindBillableObjectMetadata'] = _BINDBILLABLEOBJECTMETADATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetBillingAccountRequest = _reflection.GeneratedProtocolMessageType('GetBillingAccountRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBILLINGACCOUNTREQUEST,
  '__module__' : 'yandex.cloud.billing.v1.billing_account_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.billing.v1.GetBillingAccountRequest)
  })
_sym_db.RegisterMessage(GetBillingAccountRequest)

ListBillingAccountsRequest = _reflection.GeneratedProtocolMessageType('ListBillingAccountsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTBILLINGACCOUNTSREQUEST,
  '__module__' : 'yandex.cloud.billing.v1.billing_account_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.billing.v1.ListBillingAccountsRequest)
  })
_sym_db.RegisterMessage(ListBillingAccountsRequest)

ListBillingAccountsResponse = _reflection.GeneratedProtocolMessageType('ListBillingAccountsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTBILLINGACCOUNTSRESPONSE,
  '__module__' : 'yandex.cloud.billing.v1.billing_account_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.billing.v1.ListBillingAccountsResponse)
  })
_sym_db.RegisterMessage(ListBillingAccountsResponse)

ListBillableObjectBindingsRequest = _reflection.GeneratedProtocolMessageType('ListBillableObjectBindingsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTBILLABLEOBJECTBINDINGSREQUEST,
  '__module__' : 'yandex.cloud.billing.v1.billing_account_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.billing.v1.ListBillableObjectBindingsRequest)
  })
_sym_db.RegisterMessage(ListBillableObjectBindingsRequest)

ListBillableObjectBindingsResponse = _reflection.GeneratedProtocolMessageType('ListBillableObjectBindingsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTBILLABLEOBJECTBINDINGSRESPONSE,
  '__module__' : 'yandex.cloud.billing.v1.billing_account_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.billing.v1.ListBillableObjectBindingsResponse)
  })
_sym_db.RegisterMessage(ListBillableObjectBindingsResponse)

BindBillableObjectRequest = _reflection.GeneratedProtocolMessageType('BindBillableObjectRequest', (_message.Message,), {
  'DESCRIPTOR' : _BINDBILLABLEOBJECTREQUEST,
  '__module__' : 'yandex.cloud.billing.v1.billing_account_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.billing.v1.BindBillableObjectRequest)
  })
_sym_db.RegisterMessage(BindBillableObjectRequest)

BindBillableObjectMetadata = _reflection.GeneratedProtocolMessageType('BindBillableObjectMetadata', (_message.Message,), {
  'DESCRIPTOR' : _BINDBILLABLEOBJECTMETADATA,
  '__module__' : 'yandex.cloud.billing.v1.billing_account_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.billing.v1.BindBillableObjectMetadata)
  })
_sym_db.RegisterMessage(BindBillableObjectMetadata)


DESCRIPTOR._options = None
_GETBILLINGACCOUNTREQUEST.fields_by_name['id']._options = None
_LISTBILLINGACCOUNTSREQUEST.fields_by_name['page_size']._options = None
_LISTBILLINGACCOUNTSREQUEST.fields_by_name['page_token']._options = None
_LISTBILLABLEOBJECTBINDINGSREQUEST.fields_by_name['billing_account_id']._options = None
_LISTBILLABLEOBJECTBINDINGSREQUEST.fields_by_name['page_size']._options = None
_LISTBILLABLEOBJECTBINDINGSREQUEST.fields_by_name['page_token']._options = None
_BINDBILLABLEOBJECTREQUEST.fields_by_name['billing_account_id']._options = None

_BILLINGACCOUNTSERVICE = _descriptor.ServiceDescriptor(
  name='BillingAccountService',
  full_name='yandex.cloud.billing.v1.BillingAccountService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1099,
  serialized_end=2340,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.billing.v1.BillingAccountService.Get',
    index=0,
    containing_service=None,
    input_type=_GETBILLINGACCOUNTREQUEST,
    output_type=yandex_dot_cloud_dot_billing_dot_v1_dot_billing__account__pb2._BILLINGACCOUNT,
    serialized_options=b'\202\323\344\223\002\"\022 /billing/v1/billingAccounts/{id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.billing.v1.BillingAccountService.List',
    index=1,
    containing_service=None,
    input_type=_LISTBILLINGACCOUNTSREQUEST,
    output_type=_LISTBILLINGACCOUNTSRESPONSE,
    serialized_options=b'\202\323\344\223\002\035\022\033/billing/v1/billingAccounts',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListBillableObjectBindings',
    full_name='yandex.cloud.billing.v1.BillingAccountService.ListBillableObjectBindings',
    index=2,
    containing_service=None,
    input_type=_LISTBILLABLEOBJECTBINDINGSREQUEST,
    output_type=_LISTBILLABLEOBJECTBINDINGSRESPONSE,
    serialized_options=b'\202\323\344\223\002I\022G/billing/v1/billingAccounts/{billing_account_id}/billableObjectBindings',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='BindBillableObject',
    full_name='yandex.cloud.billing.v1.BillingAccountService.BindBillableObject',
    index=3,
    containing_service=None,
    input_type=_BINDBILLABLEOBJECTREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002L\"G/billing/v1/billingAccounts/{billing_account_id}/billableObjectBindings:\001*\262\322*3\n\032BindBillableObjectMetadata\022\025BillableObjectBinding',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListAccessBindings',
    full_name='yandex.cloud.billing.v1.BillingAccountService.ListAccessBindings',
    index=4,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._LISTACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_access_dot_access__pb2._LISTACCESSBINDINGSRESPONSE,
    serialized_options=b'\202\323\344\223\002>\022</billing/v1/billingAccounts/{resource_id}:listAccessBindings',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateAccessBindings',
    full_name='yandex.cloud.billing.v1.BillingAccountService.UpdateAccessBindings',
    index=5,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._UPDATEACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002C2>/billing/v1/billingAccounts/{resource_id}:updateAccessBindings:\001*\262\322*<\n#access.UpdateAccessBindingsMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_BILLINGACCOUNTSERVICE)

DESCRIPTOR.services_by_name['BillingAccountService'] = _BILLINGACCOUNTSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from yandex.cloud.cdn.v1 import cache_service_pb2 as yandex_dot_cloud_dot_cdn_dot_v1_dot_cache__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


class CacheServiceStub(object):
    """A set of methods for managing Cache Service resources.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Purge = channel.unary_unary(
                '/yandex.cloud.cdn.v1.CacheService/Purge',
                request_serializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_cache__service__pb2.PurgeCacheRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Prefetch = channel.unary_unary(
                '/yandex.cloud.cdn.v1.CacheService/Prefetch',
                request_serializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_cache__service__pb2.PrefetchCacheRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )


class CacheServiceServicer(object):
    """A set of methods for managing Cache Service resources.
    """

    def Purge(self, request, context):
        """Removes specified files from the cache of the specified resource. For details about purging, see [documentation](/docs/cdn/concepts/caching#purge).
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Prefetch(self, request, context):
        """Uploads specified files from origins to cache of the specified resource. For defails about prefetching, see [documentation](/docs/cdn/concepts/caching#prefetch).
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CacheServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Purge': grpc.unary_unary_rpc_method_handler(
                    servicer.Purge,
                    request_deserializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_cache__service__pb2.PurgeCacheRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Prefetch': grpc.unary_unary_rpc_method_handler(
                    servicer.Prefetch,
                    request_deserializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_cache__service__pb2.PrefetchCacheRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.cdn.v1.CacheService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class CacheService(object):
    """A set of methods for managing Cache Service resources.
    """

    @staticmethod
    def Purge(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.cdn.v1.CacheService/Purge',
            yandex_dot_cloud_dot_cdn_dot_v1_dot_cache__service__pb2.PurgeCacheRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Prefetch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.cdn.v1.CacheService/Prefetch',
            yandex_dot_cloud_dot_cdn_dot_v1_dot_cache__service__pb2.PrefetchCacheRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
